# HG changeset patch
# User Roman Telezhynskyi <kroluku@gmail.com>
# Date 1498934306 -10800
# Branch release
# Node ID d78ca13c4891ccf3542b0704a7d66af0f9b02938
# Parent  b60a78d145f51bef3bc08978e1fe3b0a7d6500ab
Fixed issue #715. Build fails with Qt 5.9.1 / clang / macOS.

diff --git a/src/app/tape/dialogs/dialogmdatabase.h b/src/app/tape/dialogs/dialogmdatabase.h
--- a/src/app/tape/dialogs/dialogmdatabase.h
+++ b/src/app/tape/dialogs/dialogmdatabase.h
@@ -91,7 +91,8 @@
     void InitGroup(QTreeWidgetItem **group, const QString &groupName, const QStringList &mList,
                    const QStringList &list = QStringList());
 
-    QTreeWidgetItem *AddGroup(const QString &text) Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QTreeWidgetItem *AddGroup(const QString &text);
+
     void AddMeasurement(QTreeWidgetItem *group, const QString &name, const QStringList &list);
 
     void ReadSettings();
diff --git a/src/app/tape/tmainwindow.h b/src/app/tape/tmainwindow.h
--- a/src/app/tape/tmainwindow.h
+++ b/src/app/tape/tmainwindow.h
@@ -175,7 +175,8 @@
 
     QTableWidgetItem *AddCell(const QString &text, int row, int column, int aligment, bool ok = true);
 
-    QComboBox *SetGradationList(QLabel *label, const QStringList &list) Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QComboBox *SetGradationList(QLabel *label, const QStringList &list);
+
     void       SetDefaultHeight(int value);
     void       SetDefaultSize(int value);
 
diff --git a/src/app/valentina/core/vformulaproperty.h b/src/app/valentina/core/vformulaproperty.h
--- a/src/app/valentina/core/vformulaproperty.h
+++ b/src/app/valentina/core/vformulaproperty.h
@@ -67,8 +67,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
     //! Sets the value of the property
     virtual void setValue(const QVariant& value) Q_DECL_OVERRIDE;
diff --git a/src/libs/ifc/exception/vexception.h b/src/libs/ifc/exception/vexception.h
--- a/src/libs/ifc/exception/vexception.h
+++ b/src/libs/ifc/exception/vexception.h
@@ -49,8 +49,10 @@
     virtual ~VException() V_NOEXCEPT_EXPR (true) Q_DECL_EQ_DEFAULT;
 
     Q_NORETURN virtual void raise() const Q_DECL_OVERRIDE;
+
     // cppcheck-suppress unusedFunction
-    virtual VException *clone() const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VException *clone() const Q_DECL_OVERRIDE;
+
     virtual QString ErrorMessage() const;
     virtual QString DetailedInformation() const;
     QString         WhatUtf8() const V_NOEXCEPT_EXPR (true);
diff --git a/src/libs/qmuparser/qmudef.h b/src/libs/qmuparser/qmudef.h
--- a/src/libs/qmuparser/qmudef.h
+++ b/src/libs/qmuparser/qmudef.h
@@ -121,7 +121,7 @@
 
 QT_WARNING_POP
 
-static inline bool QmuFuzzyComparePossibleNulls(double p1, double p2) Q_REQUIRED_RESULT;
+Q_REQUIRED_RESULT static inline bool QmuFuzzyComparePossibleNulls(double p1, double p2);
 static inline bool QmuFuzzyComparePossibleNulls(double p1, double p2)
 {
     if(qFuzzyIsNull(p1))
diff --git a/src/libs/qmuparser/qmuparsercallback.h b/src/libs/qmuparser/qmuparsercallback.h
--- a/src/libs/qmuparser/qmuparsercallback.h
+++ b/src/libs/qmuparser/qmuparsercallback.h
@@ -82,7 +82,8 @@
     QmuParserCallback(const QmuParserCallback &a_Fun);
     QmuParserCallback &operator=(const QmuParserCallback &a_Fun);
 
-    QmuParserCallback* Clone() const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QmuParserCallback* Clone() const;
+
     bool               IsOptimizable() const;
     void*              GetAddr() const;
     ECmdCode           GetCode() const;
diff --git a/src/libs/qmuparser/qmuparsererror.h b/src/libs/qmuparser/qmuparsererror.h
--- a/src/libs/qmuparser/qmuparsererror.h
+++ b/src/libs/qmuparser/qmuparsererror.h
@@ -155,7 +155,7 @@
     const QString& GetToken() const;
     EErrorCodes    GetCode() const;
     Q_NORETURN virtual void   raise() const Q_DECL_OVERRIDE;
-    virtual QmuParserError *clone() const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual QmuParserError *clone() const Q_DECL_OVERRIDE;
 private:
     QString m_sMsg;      ///< The message string
     QString m_sExpr;     ///< Formula string
diff --git a/src/libs/vdxf/dxfdef.h b/src/libs/vdxf/dxfdef.h
--- a/src/libs/vdxf/dxfdef.h
+++ b/src/libs/vdxf/dxfdef.h
@@ -40,7 +40,7 @@
 //Default drawing units for AutoCAD DesignCenter blocks:
 enum class VarInsunits : unsigned char { Inches=1, Millimeters=4, Centimeters=5 };
 
-static inline bool DL_FuzzyComparePossibleNulls(double p1, double p2) Q_REQUIRED_RESULT;
+Q_REQUIRED_RESULT static inline bool DL_FuzzyComparePossibleNulls(double p1, double p2);
 static inline bool DL_FuzzyComparePossibleNulls(double p1, double p2)
 {
     if(qFuzzyIsNull(p1))
diff --git a/src/libs/vdxf/vdxfengine.h b/src/libs/vdxf/vdxfengine.h
--- a/src/libs/vdxf/vdxfengine.h
+++ b/src/libs/vdxf/vdxfengine.h
@@ -91,7 +91,7 @@
     VarMeasurement varMeasurement;
     VarInsunits varInsunits;
 
-    double FromPixel(double pix, const VarInsunits &unit) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT double FromPixel(double pix, const VarInsunits &unit) const;
 };
 
 #endif // VDXFENGINE_H
diff --git a/src/libs/vlayout/vlayoutgenerator.h b/src/libs/vlayout/vlayoutgenerator.h
--- a/src/libs/vlayout/vlayoutgenerator.h
+++ b/src/libs/vlayout/vlayoutgenerator.h
@@ -82,8 +82,8 @@
 
     LayoutErrors State() const;
 
-    QList<QGraphicsItem *> GetPapersItems() const Q_REQUIRED_RESULT;
-    QList<QList<QGraphicsItem *>> GetAllDetails() const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QList<QGraphicsItem *> GetPapersItems() const;
+    Q_REQUIRED_RESULT QList<QList<QGraphicsItem *>> GetAllDetails() const;
 
     bool GetRotate() const;
     void SetRotate(bool value);
diff --git a/src/libs/vlayout/vlayoutpaper.h b/src/libs/vlayout/vlayoutpaper.h
--- a/src/libs/vlayout/vlayoutpaper.h
+++ b/src/libs/vlayout/vlayoutpaper.h
@@ -88,8 +88,8 @@
 
     bool ArrangeDetail(const VLayoutPiece &detail, std::atomic_bool &stop);
     int  Count() const;
-    QGraphicsRectItem *GetPaperItem(bool autoCrop) const Q_REQUIRED_RESULT;
-    QList<QGraphicsItem *> GetItemDetails() const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QGraphicsRectItem *GetPaperItem(bool autoCrop) const;
+    Q_REQUIRED_RESULT QList<QGraphicsItem *> GetItemDetails() const;
 
     QVector<VLayoutPiece> GetDetails() const;
     void                   SetDetails(const QList<VLayoutPiece>& details);
diff --git a/src/libs/vlayout/vlayoutpiece.h b/src/libs/vlayout/vlayoutpiece.h
--- a/src/libs/vlayout/vlayoutpiece.h
+++ b/src/libs/vlayout/vlayoutpiece.h
@@ -126,14 +126,14 @@
     QPainterPath ContourPath() const;
 
     QPainterPath LayoutAllowancePath() const;
-    QGraphicsItem *GetItem() const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QGraphicsItem *GetItem() const;
 
 private:
     QSharedDataPointer<VLayoutPieceData> d;
 
     QVector<QPointF> DetailPath() const;
 
-    QGraphicsPathItem *GetMainItem() const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT QGraphicsPathItem *GetMainItem() const;
 
     QPainterPath CreateLabelText(const QVector<QPointF> &labelShape, const VTextManager &tm) const;
 
diff --git a/src/libs/vmisc/def.h b/src/libs/vmisc/def.h
--- a/src/libs/vmisc/def.h
+++ b/src/libs/vmisc/def.h
@@ -735,32 +735,32 @@
 
 extern const qreal PrintDPI;
 
-double ToPixel(double val, const Unit &unit) Q_REQUIRED_RESULT;
-double FromPixel(double pix, const Unit &unit) Q_REQUIRED_RESULT;
+Q_REQUIRED_RESULT double ToPixel(double val, const Unit &unit);
+Q_REQUIRED_RESULT double FromPixel(double pix, const Unit &unit);
 
-qreal UnitConvertor(qreal value, const Unit &from, const Unit &to) Q_REQUIRED_RESULT;
+Q_REQUIRED_RESULT qreal UnitConvertor(qreal value, const Unit &from, const Unit &to);
 
 void CheckFactor(qreal &oldFactor, const qreal &Newfactor);
 
 void InitLanguages(QComboBox *combobox);
-QStringList SupportedLocales() Q_REQUIRED_RESULT;
-QStringList AllGroupNames() Q_REQUIRED_RESULT;
+Q_REQUIRED_RESULT QStringList SupportedLocales();
+Q_REQUIRED_RESULT QStringList AllGroupNames();
 
-QString StrippedName(const QString &fullFileName) Q_REQUIRED_RESULT;
-QString RelativeMPath(const QString &patternPath, const QString &absoluteMPath) Q_REQUIRED_RESULT;
-QString AbsoluteMPath(const QString &patternPath, const QString &relativeMPath) Q_REQUIRED_RESULT;
+Q_REQUIRED_RESULT QString StrippedName(const QString &fullFileName);
+Q_REQUIRED_RESULT QString RelativeMPath(const QString &patternPath, const QString &absoluteMPath);
+Q_REQUIRED_RESULT QString AbsoluteMPath(const QString &patternPath, const QString &relativeMPath);
 
-QSharedPointer<QPrinter> PreparePrinter(const QPrinterInfo &info,
-                                        QPrinter::PrinterMode mode = QPrinter::ScreenResolution) Q_REQUIRED_RESULT;
+Q_REQUIRED_RESULT QSharedPointer<QPrinter> PreparePrinter(const QPrinterInfo &info,
+                                                          QPrinter::PrinterMode mode = QPrinter::ScreenResolution);
 
 QMarginsF GetMinPrinterFields(const QSharedPointer<QPrinter> &printer);
 QMarginsF GetPrinterFields(const QSharedPointer<QPrinter> &printer);
 
-QPixmap darkenPixmap(const QPixmap &pixmap) Q_REQUIRED_RESULT;
+Q_REQUIRED_RESULT QPixmap darkenPixmap(const QPixmap &pixmap);
 
 void ShowInGraphicalShell(const QString &filePath);
 
-static inline bool VFuzzyComparePossibleNulls(double p1, double p2) Q_REQUIRED_RESULT;
+Q_REQUIRED_RESULT static inline bool VFuzzyComparePossibleNulls(double p1, double p2);
 static inline bool VFuzzyComparePossibleNulls(double p1, double p2)
 {
     if(qFuzzyIsNull(p1))
diff --git a/src/libs/vpropertyexplorer/plugins/vemptyproperty.h b/src/libs/vpropertyexplorer/plugins/vemptyproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vemptyproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vemptyproperty.h
@@ -76,8 +76,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
 protected:
     //! Protected constructor
diff --git a/src/libs/vpropertyexplorer/plugins/venumproperty.h b/src/libs/vpropertyexplorer/plugins/venumproperty.h
--- a/src/libs/vpropertyexplorer/plugins/venumproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/venumproperty.h
@@ -78,8 +78,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
     //! Sets the settings. Available settings:
     //!
diff --git a/src/libs/vpropertyexplorer/plugins/vfileproperty.h b/src/libs/vpropertyexplorer/plugins/vfileproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vfileproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vfileproperty.h
@@ -95,8 +95,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
     //! Returns whether this is a file (false) or a directory (true)
     virtual bool isDirectory() const;
diff --git a/src/libs/vpropertyexplorer/plugins/vlabelproperty.h b/src/libs/vpropertyexplorer/plugins/vlabelproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vlabelproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vlabelproperty.h
@@ -83,8 +83,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
     virtual void UpdateParent(const QVariant &value) Q_DECL_OVERRIDE;
 
diff --git a/src/libs/vpropertyexplorer/plugins/vlinecolorproperty.h b/src/libs/vpropertyexplorer/plugins/vlinecolorproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vlinecolorproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vlinecolorproperty.h
@@ -87,8 +87,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
     static int IndexOfColor(const QMap<QString, QString> &colors, const QString &color);
 
diff --git a/src/libs/vpropertyexplorer/plugins/vlinetypeproperty.h b/src/libs/vpropertyexplorer/plugins/vlinetypeproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vlinetypeproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vlinetypeproperty.h
@@ -88,8 +88,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
     static int IndexOfStyle(const QMap<QString, QIcon> &styles, const QString &style);
 
diff --git a/src/libs/vpropertyexplorer/plugins/vnumberproperty.h b/src/libs/vpropertyexplorer/plugins/vnumberproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vnumberproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vnumberproperty.h
@@ -79,8 +79,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 public slots:
     void valueChanged(int i);
 protected:
diff --git a/src/libs/vpropertyexplorer/plugins/vobjectproperty.h b/src/libs/vpropertyexplorer/plugins/vobjectproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vobjectproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vobjectproperty.h
@@ -84,8 +84,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
 public slots:
     void currentIndexChanged(int index);
diff --git a/src/libs/vpropertyexplorer/plugins/vpointfproperty.h b/src/libs/vpropertyexplorer/plugins/vpointfproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vpointfproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vpointfproperty.h
@@ -67,8 +67,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
     //! Sets the value of the property
     virtual void setValue(const QVariant& value) Q_DECL_OVERRIDE;
diff --git a/src/libs/vpropertyexplorer/plugins/vshortcutproperty.h b/src/libs/vpropertyexplorer/plugins/vshortcutproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vshortcutproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vshortcutproperty.h
@@ -71,8 +71,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
     //! Sets the value of the property
     virtual void setValue(const QVariant& value) Q_DECL_OVERRIDE;
diff --git a/src/libs/vpropertyexplorer/plugins/vstringproperty.h b/src/libs/vpropertyexplorer/plugins/vstringproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vstringproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vstringproperty.h
@@ -79,8 +79,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 
     virtual void UpdateParent(const QVariant &value) Q_DECL_OVERRIDE;
 
diff --git a/src/libs/vpropertyexplorer/plugins/vwidgetproperty.h b/src/libs/vpropertyexplorer/plugins/vwidgetproperty.h
--- a/src/libs/vpropertyexplorer/plugins/vwidgetproperty.h
+++ b/src/libs/vpropertyexplorer/plugins/vwidgetproperty.h
@@ -63,8 +63,8 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true,
-                             VProperty* container = nullptr) const Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
+                                               VProperty* container = nullptr) const Q_DECL_OVERRIDE;
 };
 
 }
diff --git a/src/libs/vpropertyexplorer/vproperty.h b/src/libs/vpropertyexplorer/vproperty.h
--- a/src/libs/vpropertyexplorer/vproperty.h
+++ b/src/libs/vpropertyexplorer/vproperty.h
@@ -199,7 +199,7 @@
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    virtual VProperty* clone(bool include_children = true, VProperty* container = nullptr) const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true, VProperty* container = nullptr) const;
 
     Property propertyType() const;
     void     setPropertyType(const Property &type);
diff --git a/src/libs/vpropertyexplorer/vpropertyset.h b/src/libs/vpropertyexplorer/vpropertyset.h
--- a/src/libs/vpropertyexplorer/vpropertyset.h
+++ b/src/libs/vpropertyexplorer/vpropertyset.h
@@ -117,7 +117,7 @@
     int getRootPropertyCount() const;
 
     //! Clones the property set
-    VPropertySet* clone() const Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT VPropertySet* clone() const;
 
 protected:
     //! Checks whether a property belongs to this set and returns the result
diff --git a/src/libs/vpropertyexplorer/vstandardpropertyfactory.h b/src/libs/vpropertyexplorer/vstandardpropertyfactory.h
--- a/src/libs/vpropertyexplorer/vstandardpropertyfactory.h
+++ b/src/libs/vpropertyexplorer/vstandardpropertyfactory.h
@@ -47,7 +47,7 @@
     //! Creates a new property of a certain type and assigns a name and description (otionally)
     //! \param type The type of the property as string
     //! \return Returns the created property or NULL if it couldn't be be created
-    virtual VProperty* createProperty(const QString& type, const QString &name) Q_DECL_OVERRIDE Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT virtual VProperty* createProperty(const QString& type, const QString &name) Q_DECL_OVERRIDE;
 };
 
 }
diff --git a/src/libs/vtools/tools/drawTools/toolpoint/toolsinglepoint/toolcut/vtoolcutsplinepath.h b/src/libs/vtools/tools/drawTools/toolpoint/toolsinglepoint/toolcut/vtoolcutsplinepath.h
--- a/src/libs/vtools/tools/drawTools/toolpoint/toolsinglepoint/toolcut/vtoolcutsplinepath.h
+++ b/src/libs/vtools/tools/drawTools/toolpoint/toolsinglepoint/toolcut/vtoolcutsplinepath.h
@@ -65,9 +65,10 @@
     enum { Type = UserType + static_cast<int>(Tool::CutSplinePath)};
     virtual void  ShowVisualization(bool show) Q_DECL_OVERRIDE;
 
-    static VPointF *CutSplinePath(qreal length, const QSharedPointer<VAbstractCubicBezierPath> &splPath,
-                                  const QString &pName, VSplinePath **splPath1,
-                                  VSplinePath **splPath2) Q_REQUIRED_RESULT;
+    Q_REQUIRED_RESULT static VPointF *CutSplinePath(qreal length,
+                                                    const QSharedPointer<VAbstractCubicBezierPath> &splPath,
+                                                    const QString &pName, VSplinePath **splPath1,
+                                                    VSplinePath **splPath2);
 protected:
     virtual void  contextMenuEvent ( QGraphicsSceneContextMenuEvent * event ) Q_DECL_OVERRIDE;
     virtual void  SaveDialog(QDomElement &domElement) Q_DECL_OVERRIDE;
